/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.server.util;

import java.io.IOException;
import java.net.ServerSocket;

import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;

public class PortUtils {

  @SuppressFBWarnings(value = "UNENCRYPTED_SERVER_SOCKET",
      justification = "this just reserves a port and doesn't need to be encrypted")
  public static int getRandomFreePort() {
    int count = 0;

    while (count < 13) {
      ServerSocket so = null;
      try {
        so = new ServerSocket(0);
        so.setReuseAddress(true);
        return so.getLocalPort();
      } catch (IOException ioe) {

      } finally {
        if (so != null) {
          try {
            so.close();
          } catch (IOException e) {}
        }
      }

      count++;
    }

    throw new RuntimeException("Unable to find port");
  }
}
